###########################################################################
#
#   Excelに記載のフォルダにあるSS7物件データの結果一覧をExcelの出力する。
#
#   (C)UNION SYSTEM Inc.
###########################################################################
import xlwings as xw
import csv
import os
from Python import Ss7Python as cmd

def main():

	# アクティブなExcelのシート
	wb : xw.Book = xw.books.active
	sheet : xw.Sheet = wb.sheets.active

	# 検索パスとバージョン
	str_parent_path : str = sheet[0, 1].value
	str_ss7_version : str = sheet[1, 1].value

	# 検索パス内のフォルダ
	folders = [
    	f for f in os.listdir(str_parent_path) if os.path.isdir(os.path.join(str_parent_path, f))
	]

	# 結果リスト
	results = ["結果1", "結果2", "結果3", "結果4", "結果5"]

	####################################################
	#
	#    『SS7 Op.Python実行』処理
	#

	cmd.Init()
	cmd.Start(str_ss7_version, 1) # 1=ログファイルをクリアする

	num_data : int = 0
	num_result : int = 0
	row : int = 8

	sheet[row, 0].value = "物件データ"
	sheet[row, 1].value = "結果名"
	sheet[row, 2].value = "構造"
	sheet[row, 3].value = "階数"
	sheet[row, 4].value = "計算ルート"
	sheet[row, 5].value = "柱検定比"
	sheet[row, 6].value = "大梁検定比"
	sheet[row, 7].value = "壁・ブレース検定比"
	sheet[row, 8].value = "保有水平耐力Qu/Qun"

	for folder in folders:
		
		str_ss7_path : str = str_parent_path + "//" + folder

		# SS7物件データを開く
		# 引数  3 = データ変換が必要な場合、開かない
		# 　　  1 = バックアップを別名保存して物件データを開く
		ss7data : cmd.Ss7Data = cmd.Open(str_ss7_path, 3, 1)
		if (ss7data is None):
			continue

		num_data += 1
		for result in results:

			# 計算結果の取得
			rst : cmd.Ss7Result = ss7data.GetResultData(result)
			if (rst is None):
				continue

			str_result_csv_path : str = str_ss7_path + "//temp00_" +  result + ".csv"

			# 結果CSVの出力
			# 引数  1 = 同一ファイルが存在する場合、上書きする
			# 　　  1 = 出力する際の記号を省略する
			# 　　  2 = 代表部材出力
			rst.ExportResultCsv("2.1.構造階高;10.1.計算ルート;7.1.検定比一覧;13.4.必要保有水平耐力比較表", str_result_csv_path, 1, 1, 2)

			# エラー情報の確認
			err : cmd.ErrInfo = cmd.GetLastError()
			if (err.IsOK() == True):

				num_result += 1
				####################################################
				#
				#    CSVファイルの内容を読み込む
				#
				kozolist: int = [0, 0, 0, 0, 0, 0] 	# 構造
				num_sou: int = 0					# 層数 = 階数+1
				str_Root : str = ""					# 計算ルート
				resio_column : float = 0.0			# 柱検定比
				resio_girder : float = 0.0			# 大梁検定比
				resio_wall : float = 0.0			# 壁・ブレース検定比
				resio_QuQun : float = 9999.999		# 保有水平耐力Qu/Qun
				with open(str_result_csv_path, encoding="cp932", newline='') as f:
					csvreader : csv.reader = csv.reader(f)
					read_type : int = 0
					read_start : bool = False
					for record in csvreader:
						if (0 == len(record)):
							read_type = 0
							read_start = False
						elif (record[0] == "<data>"):
							read_start = True
						else:
							if (record[0] == "name=構造階高"):
								read_type = 1
							if (record[0] == "name=計算ルート"):
								read_type = 2
							if (record[0] == "name=RC柱検定比一覧"):
								read_type = 3
							if (record[0] == "name=S柱検定比一覧"):
								read_type = 3
							if (record[0] == "name=SRC柱検定比一覧"):
								read_type = 3
							if (record[0] == "name=CFT柱検定比一覧"):
								read_type = 3
							if (record[0] == "name=木質柱検定比一覧"):
								read_type = 3
							if (record[0] == "name=RC梁検定比一覧"):
								read_type = 4
							if (record[0] == "name=S梁検定比一覧"):
								read_type = 4
							if (record[0] == "name=SRC梁検定比一覧"):
								read_type = 4
							if (record[0] == "name=木質梁検定比一覧"):
								read_type = 4
							if (record[0] == "name=RC耐震壁検定比一覧"):
								read_type = 5
							if (record[0] == "name=SRC耐震壁検定比一覧"):
								read_type = 5
							if (record[0] == "name=ブレース検定比一覧"):
								read_type = 5
							if (record[0] == "name=必要保有水平耐力比較表"):
								read_type = 6
							if (read_type == 1 and read_start == True):	# name=構造階高 のデータ
								if (len(record[1]) > 0) :
									if (record[2] == "RC") :
										kozolist[1] = 1
									elif (record[2] == "S") :
										kozolist[2] = 1
									elif (record[2] == "CFT") :
										kozolist[3] = 1
									elif (record[2] == "SRC") :
										kozolist[4] = 1
									elif (record[2] == "木") :
										kozolist[5] = 1
								if (record[10] == "通常層") :
									num_sou += 1
							if (read_type == 2 and read_start == True) :	# name=計算ルート のデータ
								if (str_Root == "") :
									str_Root =	record[1] 
								elif (str_Root < record[1]) :	# XとYで異なるルートのとき数字の大きい方を選ぶ
									str_Root =	record[1] 
							if (read_type == 3 and read_start == True) :	# name=xx柱検定比一覧 のデータ
								col : int = 0
								for cell in record:
									cell.strip()
									if (col > 1 and cell != "<RE>" and len(cell) > 0):
										resio : float = float(cell)
										if (resio > resio_column) :
											resio_column = resio
									col += 1
							if (read_type == 4 and read_start == True) :	# name=xx梁検定比一覧 のデータ
								col : int = 0
								for cell in record:
									cell.strip()
									if (col > 1 and cell != "<RE>" and len(cell) > 0):
										resio : float = float(cell)
										if (resio > resio_girder) :
											resio_girder = resio
									col += 1
							if (read_type == 5 and read_start == True) :	# name=xx耐震壁検定比一覧 のデータ
								col : int = 0
								for cell in record:
									cell.strip()
									if (col > 0 and cell != "<RE>" and len(cell) > 0):
										resio : float = float(cell)
										if (resio > resio_wall) :
											resio_wall = resio
									col += 1
							if (read_type == 6 and read_start == True) :	# name=必要保有水平耐力比較表 のデータ
								resio : float = float(record[9])
								if (resio > 0.0 and resio < resio_QuQun) :
									resio_QuQun = resio	
								
				####################################################
				#
				# 読み込み結果のsheetへの記載
				#
				str_Kozo : str = ""
				if (kozolist[1] == 1) : 
					str_Kozo += "RC・"
				if (kozolist[2] == 1) :
					str_Kozo += "S・"
				if (kozolist[3] == 1) :
					str_Kozo += "CFT・"
				if (kozolist[4] == 1) :
					str_Kozo += "SRC・"
				if (kozolist[5] == 1) :
					str_Kozo += "木・"
				if (len(str_Kozo) > 1) :
					str_Kozo = str_Kozo[:-1]
				row += 1
				sheet[row, 0].value = folder
				sheet[row, 1].value = result
				sheet[row, 2].value = str_Kozo
				sheet[row, 3].value = num_sou - 1
				sheet[row, 4].value = str_Root
				if (resio_column > 0.0) :
					sheet[row, 5].value = resio_column
				else :
					sheet[row, 5].value = ""
				if (resio_girder > 0.0) :
					sheet[row, 6].value = resio_girder
				else :
					sheet[row, 6].value = ""
				if (resio_wall > 0.0) :
					sheet[row, 7].value = resio_wall
				else :
					sheet[row, 7].value = ""
				if (resio_QuQun < 1000.0) :
					sheet[row, 8].value = resio_QuQun
				else :
					sheet[row, 8].value = ""
					
	if num_data > 0 :
		sheet[4, 3].value = "SS7データがみつかりました。"
		sheet[5, 3].value ="データ数 " + str(num_data) + "  結果総数 " + str(num_result) 
	else :
		sheet[4, 3].value = "SS7データがみつかりませんでした。"
		sheet[5, 3].value =""

main()